# Concurrent execution

Concurrent execution of Synopsys Detect by the same user can result in collisions as the Synopsys Detect script,
the Synopsys Detect .jar, the Synopsys Detect inspectors, and the Black Duck Signature Scanner
are each downloaded to the same default location during execution. There are also potential race conditions that
can occur when multiple concurrent runs of Synopsys Detect create or update the same Black Duck
project/version or codelocation.

Concurrent execution of Synopsys Detect runs that include Docker image inspection involves additional
challenges. For that scenario, we recommend engaging Synopsys Software Integrity Group Client Services for a solution tailored to your environment.
The rest of this page addresses scenarios that do not involved inspecting Docker images.

The recommended way for a single user to execute multiple Synopsys Detect runs concurrently and
avoid the collisions mentioned above is to:

1. Run Synopsys Detect using the [air gap](airgap.md) capability. This avoids downloading the Synopsys Detect script, .jar, or inspectors during execution.
1. Manually download and install the Black Duck Signature Scanner, and point Synopsys Detect to it. This avoids downloading the Black Duck Signature Scanner during execution.
1. Ensure that concurrent runs do not attempt to create or update the same Black Duck project/version, or the same codelocation.

To accomplish the first two:

1. Log into Black Duck, and under Tools > Legacy Downloads, download and unzip the Black Duck Signature Scanner.
1. Download the Synopsys Detect "no docker" air gap zip from [Synopsys SIG Artifactory server](https://sig-repo.synopsys.com/ui/repos/tree/General/bds-integrations-release/com/synopsys/integration/synopsys-detect) and unzip it. More details on using air gap mode can be found on the [air gap page](airgap.md).
1. Run Synopsys Detect as shown in this example:

````
java -jar {airgap dir}/synopsys-detect-{version}.jar --detect.blackduck.signature.scanner.local.path={scan.cli-yourBlackDuckVersion dir}
````
