# Downloading and Running Synopsys Detect

This page describes downloading and running Synopsys Detect.

## Deciding how to use Synopsys Detect

Before you download and run Synopsys Detect, you need to make the following decisions:

- Do you want to run Synopsys Detect before you build or after?
- In which directory do you want to run Synopsys Detect?
- Do you want to run Synopsys Detect as a script or a .jar file; this affects which version is run.
- What [tools and detectors](../components/overview.md) do you want to include or exclude?
- Do you want to run Synopsys Detect offline, or connected to Black Duck.

## Positioning Synopsys Detect in the build process

### Build mode

In [build mode](../components/detectors.md#build-detectors-versus-buildless-detectors), which is the default,
Synopsys Detect should be executed as a post-build step in the build environment of the project.
Building your project prior to running Synopsys Detect is often required for the detector to run successfully,
and helps ensure that the build artifacts are available for signature scanning.

### Buildless mode

In [buildless mode](../components/detectors.md#build-detectors-versus-buildless-detectors),
Synopsys Detect makes its best effort to discover dependencies without the benefit of
build artifacts or build tools. In buildless mode, there is no requirement that Synopsys Detect must run as a post-build step.
Results from buildless mode may be less accurate than results from build mode.

## Choosing the working directory

You can run Synopsys Detect from any directory. If you are not running Synopsys Detect from the project directory,
provide the project directory using the [source path property](../properties/configuration/paths.md#source-path). When that property is not set,
Synopsys Detect assumes the current working directory is the project directory.

## Choosing a run method (script, .jar, or Docker container)

There are three ways to run Synopsys Detect:

1. Download and run a Synopsys Detect script.
1. Download and run a Synopsys Detect .jar file.
1. Run Synopsys Detect from within a Docker container.

The primary reason to run one of the Synopsys Detect scripts is that the scripts have an auto-update feature.
By default, they always
run the latest version of the Synopsys Detect .jar file within a specific major version; downloading it for you if necessary.
When you run Synopsys Detect via one of the provided scripts, you automatically pick up fixes and new features as they are released.
Each script limits itself to a specific Synopsys Detect major version (for example, 7.y.z, or 6.y.z), unless you override
this default behavior.

| Synopsys Detect version | Script Type | Script Name |
| --- | --- | --- |
| 7 | Bash | detect7.sh |
| 7 | PowerShell | detect7.ps1 |
| 6 | Bash | detect.sh |
| 6 | PowerShell | detect.ps1 |

Instuctions and examples in this documentation that reference the scripts assume you are running
Synopsys Detect 7, so refer to detect7.sh or detect7.ps1. To run Synopsys Detect 6 instead,
simply substitute detect.sh for detect7.sh, or detect.ps1 for detect7.ps1.

The primary reason to run the Synopsys Detect .jar directly is that this method provides
direct control over the exact Synopsys Detect version;
Synopsys Detect does not automatically update in this scenario.

The primary reason to run Synopsys Detect from within a Docker container is to take advantage of the benefits of Docker containers, which include standardized run environment configuration;
Synopsys Detect does not automatically update in this scenario.

## Running the Synopsys Detect script

The primary function of the Synopsys Detect scripts is to download and execute the Synopsys Detect .jar file.
Several aspects of script functionality can be configured, including:

* The Synopsys Detect version to download/run; by default, the latest version.
* The download location.
* Where to find Java.

Information on how to configure the scripts is in [Shell script configuration](../scripts/overview.md).

### Running the script on Linux or Mac

On Linux or Mac, execute the Synopsys Detect script (detect7.sh, which is a Bash script) from Bash.

To download and run the latest version of Synopsys Detect in a single command:

````
bash <(curl -s -L https://detect.synopsys.com/detect7.sh)
````

Append any command line arguments to the end, separated by spaces. For example:

````
bash <(curl -s -L https://detect.synopsys.com/detect7.sh) --blackduck.url=https://blackduck.mydomain.com --blackduck.api.token=myaccesstoken
````

See [Quoting and escaping shell script arguments](../scripts/script-escaping-special-characters.md) for details about quoting and escaping arguments.

#### To run a specific version of Synopsys Detect:

````
export DETECT_LATEST_RELEASE_VERSION={Synopsys Detect version}
bash <(curl -s -L https://detect.synopsys.com/detect7.sh)
````

For example, to run Synopsys Detect version 5.5.0:

````
export DETECT_LATEST_RELEASE_VERSION=5.5.0
bash <(curl -s -L https://detect.synopsys.com/detect7.sh)
````

### Running the script on Windows

On Windows, execute the Synopsys Detect script (detect7.ps1, which is a PowerShell script) from
the [Command Prompt](https://en.wikipedia.org/wiki/Cmd.exe).

To download and run the latest version of Synopsys Detect in a single command:

````
powershell "[Net.ServicePointManager]::SecurityProtocol = 'tls12'; irm https://detect.synopsys.com/detect7.ps1?$(Get-Random) | iex; detect"
````

Append any command line arguments to the end, separated by spaces. For example:

````
powershell "[Net.ServicePointManager]::SecurityProtocol = 'tls12'; irm https://detect.synopsys.com/detect7.ps1?$(Get-Random) | iex; detect" --blackduck.url=https://blackduck.mydomain.com --blackduck.api.token=myaccesstoken
````

#### To run a specific version of Synopsys Detect:

````
set DETECT_LATEST_RELEASE_VERSION={Synopsys Detect version}
powershell "[Net.ServicePointManager]::SecurityProtocol = 'tls12'; irm https://detect.synopsys.com/detect7.ps1?$(Get-Random) | iex; detect"
````

For example, to run Synopsys Detect version 5.5.0:

````
set DETECT_LATEST_RELEASE_VERSION=5.5.0
powershell "[Net.ServicePointManager]::SecurityProtocol = 'tls12'; irm https://detect.synopsys.com/detect7.ps1?$(Get-Random) | iex; detect"
````

See [Quoting and escaping shell script arguments](../scripts/script-escaping-special-characters.md) for details about quoting and escaping arguments.

## Running the Synopsys Detect .jar

Recent versions of the Synopsys Detect .jar file are available for download from https://sig-repo.synopsys.com/bds-integrations-release/com/synopsys/integration/synopsys-detect.

To run Synopsys Detect by invoking the .jar file:

````
java -jar {path to .jar file}
````

For example:

````
curl -O https://sig-repo.synopsys.com/bds-integrations-release/com/synopsys/integration/synopsys-detect/5.6.2/synopsys-detect-5.6.2.jar
java -jar synopsys-detect-5.6.2.jar
````

You can use the Synopsys Detect Bash script (detect7.sh) to download the Synopsys Detect .jar file:

````
export DETECT_DOWNLOAD_ONLY=1
./detect7.sh
````

## Choosing the target type

Synopsys Detect will select a workflow based in part on the target type you select via the *detect.target.type* property.

When running Synopsys Detect on project source code, you'll probably want to
set *detect.target.type* to *SOURCE*, or leave *detect.target.type* unset (since
*SOURCE* is the default value).

When running Synopsys Detect on a Docker image, you'll probably want to
set *detect.target.type* to *IMAGE*.

### Common workflows

By default (detect.target.type=SOURCE), Synopsys Detect will run the following on the source directory:

1. Any applicable detectors
1. Black Duck Signature Scanner

When a Docker image is provided and property *detect.target.type* is set to IMAGE, Synopsys Detect will run the following on the image:

1. Docker Inspector
1. Black Duck Signature Scanner
1. Black Duck - Binary Analysis

## Running with Black Duck

Synopsys Detect can be used with Black Duck to perform Software Composition Analysis (SCA).

### Overview

When Black Duck connection details are provided, Synopsys Detect executes
the following by default:

* The [detector tool](../components/detectors.md), which runs the appropriate package manager-specific detector; the Maven detector
for Maven projects, the Gradle detector for Gradle projects, and so forth.
* The [Black Duck Signature Scanner](../properties/configuration/signature-scanner.md), which performs a Black Duck signature scan on the
project directory.

Synopsys Detect can be configured to perform additional tasks, including the following:

* Enable any of the supported snippet matching modes in the [Black Duck Signature Scanner](../properties/configuration/signature-scanner.md).
* Enable the [Vulnerability Impact Analysis Tool](../properties/configuration/impact-analysis.md#vulnerability-impact-analysis-enabled) on any Java project.
* Run [Black Duck - Binary Analysis](../properties/configuration/binary-scanner.md) on a given binary files.

* Run the Black Duck Docker Inspector on a given [Docker image](../packagemgrs/docker-images.md).
* Generate a [report](../properties/configuration/report.md).
* Fail on [policy violation](../properties/configuration/project.md#fail-on-policy-violation-severities-advanced).

Refer to [Black Duck Server properties](../properties/configuration/blackduck-server.md)
and [Black Duck Signature Scanner properties](../properties/configuration/signature-scanner.md) for details.

### Offline mode

If you do not have a Black Duck instance, or if your network is down, you can still run Synopsys Detect in offline mode.
In offline mode, Synopsys Detect creates the BDIO content and the dry run Black Duck signature scan output files without attempting to upload them to Black Duck.
You can run Synopsys Detect in offline mode using the [offline mode property](../properties/configuration/blackduck-server.md#offline-mode).

### BDIO format

Synopsys Detect produces dependency information for Black Duck in Black Duck Input Output (BDIO) format files.
Synopsys Detect can produce BDIO files in two formats: BDIO version 1, or BDIO version 2.
Versions of Black Duck prior to 2018.12.4 accept only BDIO 1.
Black Duck versions 2018.12.4 and higher accept either BDIO 1 or BDIO 2.
By default, Synopsys Detect produces BDIO 2 files.

Use the [BDIO2 enabled property](../properties/configuration/paths.md#bdio-2-enabled-deprecated) to select BDIO 1 format
(by disabling BDIO 2 format).

