# Running behind a proxy

When running behind a proxy:

1. The one-liner cannot be used to download the scripts, they do not know about proxy. The scripts must be already downloaded.
2. The script (detect7.sh or detect7.ps1) requires proxy details to do a version
check on, and/or download the Synopsys Detect .jar file.
3. Synopsys Detect; in other words, the code in the .jar file, requires proxy details to download inspectors and
connect to Black Duck and Polaris.

## Providing proxy details to Synopsys Detect

Synopsys Detect looks for proxy details in the properties whose names start with blackduck.proxy,
including:

* blackduck.proxy.host (proxy host)
* blackduck.proxy.port (proxy port)
* blackduck.proxy.username (proxy username)
* blackduck.proxy.password (proxy password)

Refer to [properties](../properties/configuration/proxy.md) for more information.

## Providing proxy details to detect7.sh

The curl commands executed by detect7.sh to do a version check on, and/or download the Synopsys Detect
.jar file, require additional command line options when run behind a proxy. For more information
on curl options, refer to the [curl documentation](https://curl.haxx.se/docs/manpage.html).

To provide additional curl command line options for detect7.sh to use
when it executes curl, set the environment variable DETECT_CURL_OPTS before running
detect7.sh. For example:

    export DETECT_CURL_OPTS=--proxy http://myproxy:3128
    ./detect7.sh

When using detect7.sh to execute Synopsys Detect you must set proxy properties
for Synopsys Detect as previously described.

## Providing proxy details to detect7.ps1

detect7.ps1 derives proxy details from environment variables
whose names match the Synopsys Detect proxy property names.
Configuring detect7.ps1 for your proxy involves
setting those environment variables before running detect7.ps1.
Note that typically, the PowerShell script is run from a Command window, using "powershell script.ps1" so these should be run in that Command window.
For example:

    set BLACKDUCK_PROXY_HOST=$ProxyHost
    set BLACKDUCK_PROXY_PORT=$ProxyPort
    set BLACKDUCK_PROXY_PASSWORD=$ProxyUsername
    set BLACKDUCK_PROXY_USERNAME=$ProxyPassword
    powershell "Import-Module FULL_PATH_TO_DOWNLOADED_SCRIPT/detect7.ps1; detect"

For additional information on these properties, including alternate key formats, see the [Shell script configuration reference](../scripts/overview.md).

When using detect7.ps1 to execute Synopsys Detect, Synopsys Detect also receives the proxy details
from these environment variables, so no additional configuration is required for Synopsys Detect.


