# Solutions to common problems

## DETECT_SOURCE was not set or computed correctly

### Symptom

detect7.sh fails with: DETECT_SOURCE was not set or computed correctly, please check your configuration and environment.

### Possible cause

detect7.sh is trying to execute this command:
````
curl --silent --header \"X-Result-Detail: info\" https://sig-repo.synopsys.com/api/storage/bds-integrations-release/com/synopsys/integration/synopsys-detect?properties=DETECT_LATEST
````
The response to this command should be similar to the following:
```
{
"properties" : {
"DETECT_LATEST" : [ "https://sig-repo.synopsys.com/bds-integrations-release/com/synopsys/integration/synopsys-detect/5.6.1/synopsys-detect-5.6.1.jar" ]
},
"uri" : "https://sig-repo.synopsys.com/api/storage/bds-integrations-release/com/synopsys/integration/synopsys-detect"
}
```
When that command does not successfully return a value for property DETECT_LATEST, detect7.sh reports:
````
DETECT_SOURCE was not set or computed correctly, please check your configuration and environment.
````

### Solution

If the curl command described above does not successfully return a value for property DETECT_LATEST, you must determine why, and make the changes necessary so that curl command works.

## Synopsys Detect succeeds, but the results are incomplete because package managers or sub-projects were overlooked

### Symptom

In this scenario, everything succeeds, but many or all components are missed. Examining the log shows that
package managers were not recognized and/or sub-projects were overlooked.

### Possible cause

The detector search depth needs to be increased. The default value (0) limits the search for package manager files to the project directory. If project manager files
are located in subdirectories and/or there are sub-projects, this depth should be increased to enable Synopsys Detect to find the relevant files, so it
will run the appropriate detector(s).

See [detector search depth](../properties/configuration/paths.md#detector-search-depth) for more details.

## Docker Inspector error fails after logging: "The Black Duck url must be specified"

### Symptom

When running a version of Synopsys Detect prior to Synopsys Detect version 5.6.0, the Synopsys Detect Status block reports DOCKER: FAILURE, and the following error appears in the Docker Inspector log:
Docker Inspector error: Error inspecting image: The Black Duck url must be specified. Either an API token or a username/password must be specified.

### Possible cause

Synopsys Detect 5.5.1 and earlier have a bug that prevent them from working with Docker Inspector 8.2.0 and newer. The fix is in Synopsys Detect 5.6.0.

### Solution

There are two possible solutions:
1. Upgrade to Synopsys Detect 5.6.0 or newer, or:
1. Configure Synopsys Detect to use Docker Inspector 8.1.6 with the argument: --detect.docker.inspector.version=8.1.6

## Synopsys Detect fails and a TRACE log shows an HTTP response from Black Duck of "402 Payment Required" or "502 Bad Gateway"

### Symptom

Synopsys Detect fails, and a TRACE log contains "402 Payment Required" or "502 Bad Gateway".

### Possible cause

Black Duck does not have a required feature (notifications, binary analysis, etc.) enabled.

### Solution

Enable the required feature on the Black Duck server.

## Unexpected behavior running Synopsys Detect on a project that uses Spring Boot

### Symptom

Unexpected behavior, and/or unexpected property values shown in the log.

### Possible cause

If your source directory contains Spring Framework configuration files named application.properties, application.yml,
or application.xml that are written for any application other than Synopsys Detect, you should not run Synopsys Detect from your source directory.

### Solution

To prevent Synopsys Detect from reading those files, run Synopsys Detect from a different directory. Use the following property to point to your source directory.
```
--detect.source.path={project directory path}
```

## PKIX error connecting to Black Duck

### Symptom

Exception: Could not communicate with Black Duck: Could not perform the authorization request: PKIX path building failed: sun.security.provider.certpath.SunCertPathBuilderException: unable to find valid certification path to requested target

### Possible cause

The Black Duck server certificate is not in Java's keystore.

### Solution

1. Acquire the certificate file for your Black Duck server.
1. Determine which *java* executable is being used to run Synopsys Detect. If you run detect7.sh or detect7.sh, that is either $JAVA_HOME/bin/java (the default) or the first *java* found on your $PATH.
1. Determine the Java home directory for that *java* executable.
1. Run [keytool](https://docs.oracle.com/en/java/javase/11/tools/keytool.html) to install the Black Duck server certificate into the keystore in that Java home directory.

Although not recommended, it is possible to disable the certificate check with the [trust cert property](../properties/configuration/blackduck-server.md#trust-all-ssl-certificates-advanced).

## Not Extractable: NUGET - Solution INFO \[main\] -- Exception occurred: java.nio.file.InvalidPathException

### Symptom

Running Synopsys Detect on a NuGet project on Windows, a message similar to the following appears in the Synopsys Detect log:

````
Not Extractable: NUGET - Solution INFO [main] -- Exception occurred: java.nio.file.InvalidPathException: Illegal char
<:> at index 2: C:\...
````

### Possible cause

The value of $PATH contains a whitespace character after a semicolon and the path mentioned in the log message.

### Solution

Remove spaces immediately following semicolons in the value of $PATH.

## No project name/version provided or derived

### Symptom

Upload to Black Duck fails with a message similar to the following in the log:

````
ERROR [main] -- createProject.arg0.name can't be blank [HTTP Error]: There was a problem trying to POST https://.../api/projects, response was 412 Precondition Failed.
````

### Possible cause

No project name and version were provided via properties and no Synopsys Detect tool capable of deriving a project name and version was included in the run. For example,
you will get this (or a similar) error if you run with --detect.tools.BINARY_SCANNER and do not set --detect.project.name or --detect.project.version.name.

### Solution

Set --detect.project.name and --detect.project.version.name.

## Black Duck Signature Scanner fails on Alpine Linux

### Symptom

The Black Duck Signature Scanner fails on Alpine Linux with an error similar to:

````
There was a problem scanning target '/opt/projects/myproject': Cannot run program "/home/me/blackduck/tools/Black_Duck_Scan_Installation/scan.cli-2020.6.0/jre/bin/java": error=2, No such
file or directory
````

### Possible cause

The Java bundled with the Black Duck Signature Scanner does not work on Alpine Linux (it relies on libraries not usually present on an Alpine system).

### Solution

Install an appropriate version of Java and tell Synopsys Detect to invoke the Black Duck Signature Scanner using that
version of Java by setting environment variable BDS_JAVA_HOME to the JAVA_HOME value for that Java installation.

For example:

````
export BDS_JAVA_HOME=$JAVA_HOME
````

Or:

````
export BDS_JAVA_HOME=/usr/lib/jvm/java-11-openjdk/jre
````

## On Windows: Error trying cleanup

### Symptom

When running on Windows, inspecting a Docker image (e.g. using --detect.docker.image or --detect.docker.tar),
during shutdown, Synopsys Detect logs messages similar to the following:
````
2020-08-14 14:31:04 DEBUG [main] --- Error trying cleanup:

java.io.IOException: Unable to delete file: C:\Users\Administrator\blackduck\runs\2020-08-14-21-28-40-106\extractions
...
Caused by: java.nio.file.FileSystemException: C:\Users\Administrator\blackduck\runs\2020-08-14-21-28-40-106\extractions\DOCKER-0\application.properties: The process cannot access the file because it is being used by another process.
````

### Possible cause

This happens when Docker fails to release its lock on the volume mounted directory when it shuts down the image inspector service container
due to [Docker for Windows issue 394](https://github.com/docker/for-win/issues/394).
The result is that Synopsys Detect cannot fully clean up its output directory,
and leaves behind empty subdirectories.
The problem may be intermittent.

### Solution

There is no harm in leaving the directories behind in the short term,
but we recommend periodically removing them if the problem occurs frequently.
Restarting Docker will force Docker to release the locks, and enable you to remove the directories.

## "SpringApplication - Application run failed" upon upgrading to Synopsys Detect 7

### Symptom

After upgrading to Synopsys Detect 7, Synopsys Detect fails with:
````
[main] ERROR org.springframework.boot.SpringApplication - Application run failed
java.lang.IllegalStateException: Unable to load config data resource from pattern 'file:./config/*/application.yaml'

Caused by: java.lang.IllegalStateException: 'config' is not a directory
````

### Possible cause

Synopsys Detect 7 upgraded to a newer version of Spring Boot (currently: 2.4.5) which by default looks for a subdirectory in the current working directory called "config".
If, instead of a directory named "config", there is a file named "config", Spring Boot (and Synopsys Detect) fail with the message given above.

### Solution

The easiest workaround is to override the default value of the Spring Boot property *spring.config.location*. If you are using a Spring Boot configuration
file such as application.properties or application.yml, set the value of *spring.config.location* so Spring Boot will find it.
That is, set it to the path of the directory in which that file resides (include a trailing slash to indicate that you are specifying a directory), or to the path of the config file itself.

If you are not using a Spring Boot configuration file, set the value of *spring.config.location* to the empty string:
````
--spring.config.location=""
````

Additional details are available in the [Spring Boot documentation](https://docs.spring.io/spring-boot/docs/2.4.5/reference/html/howto.html#howto-change-the-location-of-external-properties).

